@@ -8,15 +8,18 @@ import wrapt
 import tqdm
 import requests
 
-logger_debug = logging.debug
-logger_info = logging.info
-logger_warn = logging.warning
-logger_error = logging.error
+logger = logging.getLogger('dao')
+logger.setLevel(logging.WARNING)
 
+logger_debug = logger.debug
+logger_info = logger.info
+logger_warn = logger.warning
+logger_error = logger.error
 
 TMP_PATH_CACHE = 'tmp_cache'
 
 
+
 def save_cache_to_file(if_read_cache_key=None):
     """加上装饰器就会保存函数结果到文件，装饰器设置if_read_cache_key字符床，函数定义时设置对应名称参数，并在调用时设置True可从文件读cache"""
     if if_read_cache_key and not os.path.exists(TMP_PATH_CACHE):
@@ -87,6 +90,9 @@ class Dao(object):
     志：主要是指目标，只有通过势能才能达到，势就是火箭助推器形成的力量。
     """
 
+    # show_process = tqdm.tqdm
+    show_process = iter
+
     def __init__(
             self, shi_func=None,
             shu_func=None,
@@ -119,9 +125,9 @@ class Dao(object):
             self,
             shi_func=list,
             shu_func=None,
-            fa_func: typing.Union[list, iter, typing.Callable, None] = list,  *args: typing.Any, **kwargs: typing.Any):
+            fa_func: typing.Union[list, iter, typing.Callable, None] = list, *args: typing.Any, **kwargs: typing.Any):
         # 万物之道
-        return self.__class__(shi_func, shu_func, fa_func, self.zhi().wan_wu)
+        return self.__class__(shi_func, shu_func, fa_func, self.zhi(*args, **kwargs).wan_wu)
 
     def __call__(self, *args: typing.Any, **kwargs: typing.Any) -> typing.Any:
         return self.zhi(*args, **kwargs).wan_wu
@@ -149,7 +155,10 @@ class Dao(object):
         start_time = time.time()
         logger_info('[开始] 生产 [{}()] {}'.format(
             self.shi_func.__name__, ('新参数', args, kwargs, '固定参数', self.args, self.kwargs)))
-        self.san = self.shi_func(*self.args, *args, **self.kwargs, **kwargs)
+        if args or kwargs:
+            self.args, self.kwargs = args, kwargs
+        self.san = self.shi_func(*self.args, **self.kwargs)
+
         if self.fa_func is list:
             self.wan_wu = self.for_do_list(self.qi_func, self.san)
         elif self.fa_func is iter:
@@ -170,7 +179,7 @@ class Dao(object):
         filter_res_num = 0
 
         logger_info('[开始] 消费 [{}()] {}'.format(func.__name__, its.__class__))
-        for index, it in tqdm.tqdm(enumerate(its)):
+        for index, it in enumerate(cls.show_process(its)):
             res = func(it)
             time_use = time.time() - start_time
             if index < log_size or (not index % log_re):
@@ -194,7 +203,7 @@ class Dao(object):
         all_num = 0
         filter_res_num = 0
         logger_info('[开始] 消费 [{}()] {}'.format(func.__name__, its.__class__))
-        for index, it in tqdm.tqdm(enumerate(its)):
+        for index, it in enumerate(cls.show_process(its)):
             res = func(it)
             time_use = time.time() - start_time
             if index < log_size or (not index % log_re):
@@ -213,12 +222,16 @@ class Dao(object):
         return results
 
 
-if __name__ == '__main__':
+def active_log():
     logging.basicConfig(
         level=logging.INFO,
         format="[%(asctime)s] %(levelname)s [%(name)s:%(lineno)s] %(message)s",
         datefmt="%Y-%m-%d %H:%M:%S"
     )
+    logger.setLevel(logging.INFO)
+
+
+if __name__ == '__main__':
     tmp_logger_debug = functools.partial(print, '[DEBUG]')
     logger_debug = lambda x: tmp_logger_debug(repr(x))
     Dao(range, print)(1, 10)
